==> phpAdsNew_1.4.9.tar.gz: phpAdsNew_1.4.9/admin.php <==
<?
if (isset($pageid) && $pageid =="client")
{
 Header("Location: ./index.php");
exit;
}
if (!isset($pageid))
{
$pageid = "admin";
}

require ("config.php");
require("kcsm.php");

kc_auth_admin();

page_header("$phpAds_name: $strAdminstration");
show_nav("1");

unset($Session["clientID"]);

function make_options($description)
  {
  global $res_clients;
  @mysql_data_seek($res_clients, 0);
  echo "<tr>";
  echo "<td>$description:</td>";
  echo '<td><select name="clientID">';
  while ($row_clients = mysql_fetch_array($res_clients))
        {
        echo "<option value=$row_clients[clientID]>$row_clients[clientname]";
        }
  echo "</select></td>";      
  echo "<td><input type=submit value=\"$GLOBALS[strGo]\"></td>";
  echo "</tr>";
  }

// total number of clients
$res_clients = mysql_db_query($phpAds_db, "SELECT * FROM $phpAds_tbl_clients ORDER BY clientname") or mysql_die();

$res_tot_adviews = mysql_db_query($phpAds_db, "SELECT count(*) as qnt FROM $phpAds_tbl_adviews") or mysql_die();
$res_tot_adclicks = mysql_db_query($phpAds_db, "SELECT count(*) as qnt FROM $phpAds_tbl_adclicks") or mysql_die();
$row_tot_adviews = mysql_fetch_array($res_tot_adviews);
$row_tot_adclicks = mysql_fetch_array($res_tot_adclicks);
$adviews = $row_tot_adviews["qnt"];
$adclicks = $row_tot_adclicks["qnt"];

if (isset($message))
   {
   show_message($message);
   }

echo "<a href=client.php?pageid=$pageid>$strAddClient</a>";
?>
<script language="JavaScript">
<!--
function confirm_delete()
{
    if(confirm('<? print($strConfirmDeleteClient);?>'))
    {
        document.client_delete.submit();
    }
}
//-->
</script>
<form action="client.php" method="post">
 <input type="hidden" name="pageid" value="<? echo ($pageid) ?>">
<table width="100%">
<?
make_options($strModifyClient);
?>
</form>

<form action="clientdelete.php" method="post" name="client_delete">
 <input type="hidden" name="pageid" value="<? echo ($pageid) ?>">
<?
  @mysql_data_seek($res_clients, 0);
  echo "<tr>";
  echo "<td>$strDeleteClient:</td>";
  echo '<td><select name="clientID">';
  while ($row_clients = mysql_fetch_array($res_clients))
        {
        echo "<option value=$row_clients[clientID]>$row_clients[clientname]";
        }
  echo "</select></td>";
  echo "<td><input type=submit value=\"$GLOBALS[strGo]\" onClick=\"confirm_delete(); return false;\"></td>";
  echo "</tr>";
?>
</form>

<form action="banner.php" method="post">
 <input type="hidden" name="pageid" value="<? echo ($pageid) ?>">
<?
make_options($strBannerAdmin);
?>
</form>

<form action="clientstats.php" method="post">
 <input type="hidden" name="pageid" value="<? echo ($pageid) ?>">
<?
make_options($strViewClientStats);
?>
</form>
      <tr>
       <td bgcolor="#CCCCCC">Total AdViews:</td>
       <td bgcolor="#CCCCCC" colspan="2"><b><?print($adviews);?></b></td>
      </tr>
      <tr>
       <td bgcolor="#CCCCCC">Total AdClicks:</td>
       <td bgcolor="#CCCCCC" colspan="2"><b><?print($adclicks);?></b></td>
      </tr>
</table>

<?
 page_footer();
?>

==> phpAdsNew_1.5.0.tar.gz: phpAdsNew_1.5.0/admin.php <==
<?
if (isset($pageid) && $pageid =="client")
{
 Header("Location: ./index.php");
exit;
}
if (!isset($pageid))
{
$pageid = "admin";
}

require ("config.php");
require("kcsm.php");

kc_auth_admin();

page_header("$strAdminstration");
show_nav("1");

unset($Session["clientID"]);

function make_options($description)
  {
  global $res_clients;
  @mysql_data_seek($res_clients, 0);
  echo "<tr>";
  echo "<td>$description:</td>";
  echo '<td><select name="clientID">';
  while ($row_clients = mysql_fetch_array($res_clients))
        {
        echo "<option value=$row_clients[clientID]>$row_clients[clientname]";
        }
  echo "</select></td>";      
  echo "<td><input type=submit value=\"$GLOBALS[strGo]\"></td>";
  echo "</tr>";
  }

// total number of clients
$res_clients = mysql_db_query($phpAds_db, "SELECT * FROM $phpAds_tbl_clients ORDER BY clientname") or mysql_die();

$res_tot_adviews = mysql_db_query($phpAds_db, "SELECT count(*) as qnt FROM $phpAds_tbl_adviews") or mysql_die();
$res_tot_adclicks = mysql_db_query($phpAds_db, "SELECT count(*) as qnt FROM $phpAds_tbl_adclicks") or mysql_die();
$row_tot_adviews = mysql_fetch_array($res_tot_adviews);
$row_tot_adclicks = mysql_fetch_array($res_tot_adclicks);
$adviews = $row_tot_adviews["qnt"];
$adclicks = $row_tot_adclicks["qnt"];
$ctr = round($adclicks/$adviews*100,2);

if (isset($message))
   {
   show_message($message);
   }

echo "<a href=client.php?pageid=$pageid>$strAddClient</a>";
?>
<script language="JavaScript">
<!--
function confirm_delete()
{
    if(confirm('<? print($strConfirmDeleteClient);?>'))
    {
        document.client_delete.submit();
    }
}
//-->
</script>
<form action="client.php" method="post">
 <input type="hidden" name="pageid" value="<? echo ($pageid) ?>">
<table width="100%">
<?
make_options($strModifyClient);
?>
</form>

<form action="clientdelete.php" method="post" name="client_delete">
 <input type="hidden" name="pageid" value="<? echo ($pageid) ?>">
<?
  @mysql_data_seek($res_clients, 0);
  echo "<tr>";
  echo "<td>$strDeleteClient:</td>";
  echo '<td><select name="clientID">';
  while ($row_clients = mysql_fetch_array($res_clients))
        {
        echo "<option value=$row_clients[clientID]>$row_clients[clientname]";
        }
  echo "</select></td>";
  echo "<td><input type=submit value=\"$GLOBALS[strGo]\" onClick=\"confirm_delete(); return false;\"></td>";
  echo "</tr>";
?>
</form>

<form action="banner.php" method="post">
 <input type="hidden" name="pageid" value="<? echo ($pageid) ?>">
<?
make_options($strBannerAdmin);
?>
</form>

<form action="clientstats.php" method="post">
 <input type="hidden" name="pageid" value="<? echo ($pageid) ?>">
<?
make_options($strViewClientStats);
?>
</form>
      <tr>
       <td bgcolor="#CCCCCC">Total AdViews:</td>
       <td bgcolor="#CCCCCC" colspan="2"><b><?print($adviews);?></b></td>
      </tr>
      <tr>
       <td bgcolor="#CCCCCC">Total AdClicks:</td>
       <td bgcolor="#CCCCCC" colspan="2"><b><?print($adclicks);?></b></td>
      </tr>
      <tr>
       <td bgcolor="#CCCCCC">Click-Through Ratio:</td>
       <td bgcolor="#CCCCCC" colspan="2"><b><?print($ctr);?>%</b></td>
      </tr>
</table>

<a href="logout.php">Logout</a>

<?
 page_footer();
?>
